@@ -1,4 +1,4 @@
-# $Id: Directory.pm 40422 2013-10-14 09:00:20Z anton $
+# $Id: Directory.pm 40424 2013-10-14 12:41:18Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -337,7 +337,6 @@ sub listUnsuspended {
 	return $self->getUIDsByFilter($filter);
 }
 
-
 sub searchLdap {
 	my $ldap = $self->ldap_connection();
 	my @aggregatedEntries = ();
@@ -345,7 +344,7 @@ sub searchLdap {
 	if ($self->usePagedResults) {
 		my $page = Net::LDAP::Control::Paged->new( size => 500 );
 		while (1) {
-			my $search = $ldap->search(@_, contrl => [$page]);
+			my $search = $ldap->search(@_, control => [$page]);
 			push (@aggregatedEntries, $search->entries);
 			my ($resp) = $search->control( LDAP_CONTROL_PAGED ) or last;
 			my $cookie = $resp->cookie or last;
